==> mysql-connector-net-8.0.22-src.zip: EFCore/src/Storage/Internal/MySQLExecutionStrategy.cs <==
﻿// Copyright (c) 2020 Oracle and/or its affiliates.
//
// This program is free software; you can redistribute it and/or modify
// it under the terms of the GNU General Public License, version 2.0, as
// published by the Free Software Foundation.
//
// This program is also distributed with certain software (including
// but not limited to OpenSSL) that is licensed under separate terms,
// as designated in a particular file or component or in included license
// documentation.  The authors of MySQL hereby grant you an
// additional permission to link the program and your derivative works
// with the separately licensed software that they have included with
// MySQL.
//
// Without limiting anything contained in the foregoing, this file,
// which is part of MySQL Connector/NET, is also subject to the
// Universal FOSS Exception, version 1.0, a copy of which can be found at
// http://oss.oracle.com/licenses/universal-foss-exception.
//
// This program is distributed in the hope that it will be useful, but
// WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
// See the GNU General Public License, version 2.0, for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software Foundation, Inc.,
// 51 Franklin St, Fifth Floor, Boston, MA 02110-1301  USA

using Microsoft.EntityFrameworkCore;
using Microsoft.EntityFrameworkCore.Storage;
using MySql.Data.EntityFrameworkCore.Properties;
using System;
using System.Threading;
using System.Threading.Tasks;

namespace MySql.Data.EntityFrameworkCore.Storage.Internal
{
  internal class MySQLExecutionStrategy : IExecutionStrategy
  {
    private ExecutionStrategyDependencies Dependencies { get; }

    /// <summary>
    ///     This API supports the Entity Framework Core infrastructure and is not intended to be used
    ///     directly from your code. This API may change or be removed in future releases.
    /// </summary>
    public MySQLExecutionStrategy([NotNull] ExecutionStrategyDependencies dependencies)
    {
      Dependencies = dependencies;
    }

    /// <summary>
    ///     This API supports the Entity Framework Core infrastructure and is not intended to be used
    ///     directly from your code. This API may change or be removed in future releases.
    /// </summary>
    public virtual bool RetriesOnFailure => false;

    /// <summary>
    ///     This API supports the Entity Framework Core infrastructure and is not intended to be used
    ///     directly from your code. This API may change or be removed in future releases.
    /// </summary>
    public virtual TResult Execute<TState, TResult>(
        TState state,
        Func<DbContext, TState, TResult> operation,
        Func<DbContext, TState, ExecutionResult<TResult>> verifySucceeded)
    {
      try
      {
        return operation(Dependencies.CurrentContext.Context, state);
      }
      catch (Exception ex) when (ExecutionStrategy.CallOnWrappedException(ex, MySQLTransientExceptionDetector.ShouldRetryOn))
      {
        throw new InvalidOperationException(MySQLStrings.TransientExceptionDetected, ex);
      }
    }

    /// <summary>
    ///     This API supports the Entity Framework Core infrastructure and is not intended to be used
    ///     directly from your code. This API may change or be removed in future releases.
    /// </summary>
    public virtual async Task<TResult> ExecuteAsync<TState, TResult>(
        TState state,
        Func<DbContext, TState, CancellationToken, Task<TResult>> operation,
        Func<DbContext, TState, CancellationToken, Task<ExecutionResult<TResult>>> verifySucceeded,
        CancellationToken cancellationToken)
    {
      try
      {
        return await operation(Dependencies.CurrentContext.Context, state, cancellationToken);
      }
      catch (Exception ex) when (ExecutionStrategy.CallOnWrappedException(ex, MySQLTransientExceptionDetector.ShouldRetryOn))
      {
        throw new InvalidOperationException(MySQLStrings.TransientExceptionDetected, ex);
      }
    }
  }
}

==> mysql-connector-net-8.0.29-src.zip: EFCore/src/Storage/Internal/MySQLExecutionStrategy.cs <==
﻿// Copyright (c) 2020 Oracle and/or its affiliates.
//
// This program is free software; you can redistribute it and/or modify
// it under the terms of the GNU General Public License, version 2.0, as
// published by the Free Software Foundation.
//
// This program is also distributed with certain software (including
// but not limited to OpenSSL) that is licensed under separate terms,
// as designated in a particular file or component or in included license
// documentation.  The authors of MySQL hereby grant you an
// additional permission to link the program and your derivative works
// with the separately licensed software that they have included with
// MySQL.
//
// Without limiting anything contained in the foregoing, this file,
// which is part of MySQL Connector/NET, is also subject to the
// Universal FOSS Exception, version 1.0, a copy of which can be found at
// http://oss.oracle.com/licenses/universal-foss-exception.
//
// This program is distributed in the hope that it will be useful, but
// WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
// See the GNU General Public License, version 2.0, for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software Foundation, Inc.,
// 51 Franklin St, Fifth Floor, Boston, MA 02110-1301  USA

using Microsoft.EntityFrameworkCore;
using Microsoft.EntityFrameworkCore.Storage;
using MySql.EntityFrameworkCore.Properties;
using System;
using System.Threading;
using System.Threading.Tasks;

namespace MySql.EntityFrameworkCore.Storage.Internal
{
  internal class MySQLExecutionStrategy : IExecutionStrategy
  {
    private ExecutionStrategyDependencies Dependencies { get; }

    /// <summary>
    ///     This API supports the Entity Framework Core infrastructure and is not intended to be used
    ///     directly from your code. This API may change or be removed in future releases.
    /// </summary>
    public MySQLExecutionStrategy([NotNull] ExecutionStrategyDependencies dependencies)
    {
      Dependencies = dependencies;
    }

    /// <summary>
    ///     This API supports the Entity Framework Core infrastructure and is not intended to be used
    ///     directly from your code. This API may change or be removed in future releases.
    /// </summary>
    public virtual bool RetriesOnFailure => false;

    /// <summary>
    ///     This API supports the Entity Framework Core infrastructure and is not intended to be used
    ///     directly from your code. This API may change or be removed in future releases.
    /// </summary>
    public virtual TResult Execute<TState, TResult>(
        TState state,
        Func<DbContext, TState, TResult> operation,
        Func<DbContext, TState, ExecutionResult<TResult>> verifySucceeded)
    {
      try
      {
        return operation(Dependencies.CurrentContext.Context, state);
      }
      catch (Exception ex) when (ExecutionStrategy.CallOnWrappedException(ex, MySQLTransientExceptionDetector.ShouldRetryOn))
      {
        throw new InvalidOperationException(MySQLStrings.TransientExceptionDetected, ex);
      }
    }

    /// <summary>
    ///     This API supports the Entity Framework Core infrastructure and is not intended to be used
    ///     directly from your code. This API may change or be removed in future releases.
    /// </summary>
    public virtual async Task<TResult> ExecuteAsync<TState, TResult>(
        TState state,
        Func<DbContext, TState, CancellationToken, Task<TResult>> operation,
        Func<DbContext, TState, CancellationToken, Task<ExecutionResult<TResult>>> verifySucceeded,
        CancellationToken cancellationToken)
    {
      try
      {
        return await operation(Dependencies.CurrentContext.Context, state, cancellationToken);
      }
      catch (Exception ex) when (ExecutionStrategy.CallOnWrappedException(ex, MySQLTransientExceptionDetector.ShouldRetryOn))
      {
        throw new InvalidOperationException(MySQLStrings.TransientExceptionDetected, ex);
      }
    }
  }
}
